#!/usr/bin/env perl

use strict;

if (scalar(@ARGV) != 1) {
	print "You must pass 1 index filename.\n";
	exit 1;
}

open(IDX,$ARGV[0]) or die("Unable to open index file ".$ARGV[0]);
my $version = <IDX>;
if ($version =~ /^R/) {
	$version = 1;
} elsif ($version =~ /^V:([0-9]+)/) {
	$version = $1;
} else {
	print "Unknown index version.\n";
	close(IDX);
	exit(1);
}

if ($version == 1) {
	print "RestoreKey\tType\tDate\t\t\t\tItem\t\tName\n";
} else {
	print "RestoreKey\tType\tDate\t\t\t\tItem\t\tExtra\t\tName\n";
}

while (<IDX>) {
	my @items = split(/:/, $_);

	my ($end);
	my ($type, $rk, $date, $itype, $inc, $name, $extra);
	if ($items[0] =~ /^C/) {
		$type = "Folder";
		$rk = $items[6];
		$date = localtime($items[8]);
		$itype = $items[9];
		if ($version >= 3) {
			splice(@items, 0, 11);
		} else {
			splice(@items, 0, 10);
		}
	} elsif ($items[0] =~ /^M/) {
		$type = "Message";
		$rk = $items[4];
		$date = localtime($items[5]);
		$itype = $items[6];
		if ($version >= 2) {
			if ($itype eq "IPM.Appointment") {
				$extra = localtime($items[9])."\t".localtime($items[10]);
				$end = 11;
			} elsif ($itype eq "IPM.Task") {
				if ($items[9] == 0) {
					$extra = "<no due date>";
				} else {
					$extra = localtime($items[9]);
				}
				$end = 10;
			} elsif ($itype eq "IPM.StickyNote" || $itype eq "IPM.Note" || $itype eq "IPM.Contact") {
				$extra = $items[9];
				$end = 10;
			} else {
				$extra = "";
				$end = 9;
			}
		} else {
			# set to null
			$end = 8;
		}
		splice(@items, 0, $end);
	} else {
		next;
	}
	$name = join(':', @items);

	my $line = join("\t",($rk,$type,$date,$itype,$extra,$name));
	print $line;
}
close(IDX);
